@@ -47,6 +47,8 @@ public:
     return m_object_set.contains(obj);
   }
 
+  bool linksInitialised() const { return !m_list->firstTime(); }
+
 signals:
   void highlightMe();  
   void hasNewObjects();
@@ -58,6 +60,7 @@ signals:
   void showContext(QASObject*);
   void follow(QString, bool);
   void deleteObject(QASObject*);
+  void editObject(QASObject*);
 
 protected slots:
   virtual void update();
