@@ -61,7 +61,7 @@ void CollectionWidget::onLoadOlderClicked() {
 //------------------------------------------------------------------------------
 
 void CollectionWidget::updateLoadOlderButton(bool wait) {
-  if (!m_list->size() || m_list->nextLink().isEmpty()) {
+  if (m_list->nextLink().isEmpty()) {
     m_loadOlderButton->setVisible(false);
     m_itemLayout->removeWidget(m_loadOlderButton);
     return;
@@ -139,13 +139,14 @@ bool CollectionWidget::isFullObject(QASActivity* act) {
   QASObject* obj = act->object();
   bool objAlreadyShown = obj && m_objects_shown.contains(obj);
   QASActor* actor = act->actor();
-  bool directedAtYou = (act->to() && act->to()->containsYou()) ||
-    (act->cc() && act->cc()->containsYou());
+  bool directedAtYou = ((act->to() && act->to()->containsYou()) ||
+			(act->cc() && act->cc()->containsYou())) &&
+    !act->skipNotify();
   bool hiddenActor = actor && actor->isHidden();
 
   return (!(hiddenActor && !directedAtYou) &&
-          (verb == "post" ||
-           (verb == "share" && !objAlreadyShown)));
+          ((verb == "post" || verb == "share") && 
+	   (!objAlreadyShown || directedAtYou)));
 }
 
 //------------------------------------------------------------------------------
