@@ -21,6 +21,7 @@
 #include "pumpa_defines.h"
 #include "util.h"
 #include "shortobjectwidget.h"
+#include "pumpasettings.h"
 
 #include <QDesktopServices>
 #include <QMessageBox>
@@ -44,6 +45,7 @@ FullObjectWidget::FullObjectWidget(QASObject* obj, QWidget* parent,
   m_commentButton(NULL),
   m_followButton(NULL),
   m_deleteButton(NULL),
+  m_editButton(NULL),
   m_object(NULL),
   m_actor(NULL),
   m_author(NULL),
@@ -103,6 +105,10 @@ FullObjectWidget::FullObjectWidget(QASObject* obj, QWidget* parent,
   connect(m_deleteButton, SIGNAL(clicked()), this, SLOT(onDeleteClicked()));
   m_buttonLayout->addWidget(m_deleteButton, 0, Qt::AlignTop);
 
+  m_editButton = new TextToolButton(tr("edit"), this);
+  connect(m_editButton, SIGNAL(clicked()), this, SLOT(onEditClicked()));
+  m_buttonLayout->addWidget(m_editButton, 0, Qt::AlignTop);
+
   m_commentButton = new TextToolButton(tr("comment"), this);
   connect(m_commentButton, SIGNAL(clicked()), this, SLOT(reply()));
   m_buttonLayout->addWidget(m_commentButton, 0, Qt::AlignTop);
@@ -113,6 +119,18 @@ FullObjectWidget::FullObjectWidget(QASObject* obj, QWidget* parent,
 
   m_buttonLayout->addStretch();
 
+#ifdef DEBUG_BUTTONS
+  m_loadRepliesButton = new TextToolButton("R", this);
+  connect(m_loadRepliesButton, SIGNAL(clicked()),
+	  this, SLOT(onLoadRepliesClicked()));
+  m_buttonLayout->addWidget(m_loadRepliesButton, 0, Qt::AlignTop);
+
+  m_dumpJsonButton = new TextToolButton("J", this);
+  connect(m_dumpJsonButton, SIGNAL(clicked()),
+	  this, SLOT(onDumpJsonClicked()));
+  m_buttonLayout->addWidget(m_dumpJsonButton, 0, Qt::AlignTop);
+#endif
+
   m_commentsLayout = new QVBoxLayout;
 
   rightLayout->addLayout(m_contentLayout);
@@ -186,12 +204,7 @@ void FullObjectWidget::changeObject(QASAbstractObject* obj) {
     m_lessButton->setVisible(true);
   }
 
-  if (!m_object->displayName().isEmpty()) {
-    m_titleLabel->setText("<b>" + m_object->displayName() + "</b>");
-    m_titleLabel->setVisible(true);
-  } else {
-    m_titleLabel->setVisible(false);
-  }
+  updateTitle();
 
   if (objType == "image") {
     m_imageLabel->setVisible(true);
@@ -222,23 +235,8 @@ void FullObjectWidget::changeObject(QASAbstractObject* obj) {
     connect(m_author, SIGNAL(changed()),
             this, SLOT(updateFollowAuthorButton()));
   }
-  // m_commentable = objType == "note" || objType == "comment" ||
-  //   objType == "image" || objType == "video";
-  m_commentable = objType != "person";
-  if (m_commentable) {
-    m_favourButton->setVisible(true);
-    m_shareButton->setVisible(true);
-    m_deleteButton->setVisible(m_author && m_author->isYou());
-    m_commentButton->setVisible(true);
-  } else {
-    m_favourButton->setVisible(false);
-    m_shareButton->setVisible(false);
-    m_deleteButton->setVisible(false);
-    m_commentButton->setVisible(false);
-  }
   
   updateFollowAuthorButton();
-  //m_followAuthorButton->setVisible(m_commentable && notFollowingFOO);
 
   m_followButton->setVisible(objType == "person");
 
@@ -252,6 +250,17 @@ void FullObjectWidget::changeObject(QASAbstractObject* obj) {
 
 //------------------------------------------------------------------------------
 
+void FullObjectWidget::updateTitle() {
+  if (!m_object->displayName().isEmpty()) {
+    m_titleLabel->setText("<b>" + m_object->displayName() + "</b>");
+    m_titleLabel->setVisible(true);
+  } else {
+    m_titleLabel->setVisible(false);
+  }
+}
+
+//------------------------------------------------------------------------------
+
 bool FullObjectWidget::hasValidIrtObject() {
   QASObject* irtObj = m_object->inReplyTo();
   return irtObj && !irtObj->id().isEmpty();
@@ -263,6 +272,26 @@ void FullObjectWidget::onChanged() {
   if (!m_object)
     return;
 
+  m_commentable = m_object->type() != "person" && !m_object->isDeleted();
+  if (m_commentable) {
+    bool isYours = m_author && m_author->isYou();
+
+    m_favourButton->setVisible(true);
+    m_shareButton->setVisible(true);
+    m_deleteButton->setVisible(isYours);
+    m_editButton->setVisible(isYours);
+    m_commentButton->setVisible(true);
+  } else {
+    m_favourButton->setVisible(false);
+    m_shareButton->setVisible(false);
+    m_deleteButton->setVisible(false);
+    m_editButton->setVisible(false);
+    m_commentButton->setVisible(false);
+  }
+
+  if (m_object->isDeleted())
+    m_imageLabel->setVisible(false);
+
   updateLikes();
   updateShares();
 
@@ -286,12 +315,13 @@ void FullObjectWidget::onChanged() {
 
   updateInfoText();
 
+  updateTitle();
+
   QASObjectList* ol = m_object->replies();
   if (ol) {
     connect(ol, SIGNAL(changed()), this, SLOT(onChanged()),
             Qt::UniqueConnection);
-    if (ol->size() > 0)
-      addObjectList(ol);
+    addObjectList(ol);
   }
 }
 
@@ -315,11 +345,18 @@ void FullObjectWidget::updateInfoText() {
     QString location = m_actor->location();
     if (!location.isEmpty())
       infoStr += " " + QString(tr("at %1")).arg(location);
+    if (m_actor->updatedDate().isValid())
+      infoStr += ".<br/>" + QString(tr("Profile last updated %1")).
+	arg(relativeFuzzyTime(m_actor->updatedDate(), true));
   } else {
     infoStr = QString("<a href=\"%2\">%1</a>").
       arg(relativeFuzzyTime(m_object->published())).
       arg(m_object->url());
 
+    if (m_object->published() != m_object->updatedDate())
+      infoStr += ", " + QString(tr("updated %1")).
+	arg(relativeFuzzyTime(m_object->updatedDate()));
+
     QASActor* author = m_object->author();
     if (author)
       infoStr = QString("<a href=\"%2\">%1</a>").
@@ -405,18 +442,27 @@ void FullObjectWidget::updateFollowAuthorButton(bool /*wait*/) {
 //------------------------------------------------------------------------------
 
 void FullObjectWidget::updateImage() {
-  FileDownloader* fd = FileDownloader::get(m_imageUrl, true);
-  connect(fd, SIGNAL(fileReady()), this, SLOT(updateImage()),
-          Qt::UniqueConnection);
+  FileDownloadManager* fdm = FileDownloadManager::getManager();
 
-  if (fd->ready() && fd->supportsAnimation()) {
-    QMovie* mov = fd->movie();
-    m_imageLabel->setMovie(mov);
-    qDebug() << "Animated GIF" << fd->fileName();
-    mov->start();
+  if (fdm->hasFile(m_imageUrl)) {
+    if (fdm->supportsAnimation(m_imageUrl)) {
+      QMovie* mov = fdm->movie(m_imageUrl);
+      m_imageLabel->setMovie(mov);
+      mov->start();
+    } else {
+      m_imageLabel->setPixmap(fdm->pixmap(m_imageUrl,
+					  ":/images/image_broken.png"));
+    }
   } else {
-    m_imageLabel->setPixmap(fd->pixmap(":/images/broken_image.png"));
+    m_imageLabel->setPixmap(QPixmap(":/images/image_downloading.png"));
+
+    if (!m_imageUrl.isEmpty()) {
+      FileDownloader* fd = fdm->download(m_imageUrl);
+      connect(fd, SIGNAL(fileReady()), this, SLOT(updateImage()),
+	      Qt::UniqueConnection);
+    }
   }
+
 }    
 
 //------------------------------------------------------------------------------
@@ -508,28 +554,31 @@ void FullObjectWidget::addObjectList(QASObjectList* ol) {
     For now we sort by time, or more accurately by whatever number the
     QASObject::sortInt() returns. Higher number is newer, goes further
     down the list.
-  
-    Comments' lists returned by the pump API are with newest at the
-    top, so we start from the end, and can assume that the next one is
-    always newer.
-  */
+    */
 
-  int i = 0; // index into m_repliesList
   for (size_t j=0; j<ol->size(); j++) {
     QASObject* replyObj = ol->at(ol->size()-j-1);
     QString replyId = replyObj->id();
     qint64 sortInt = replyObj->sortInt();
 
+    // skip existing or deleted items
+    if (m_repliesMap.contains(replyId) || replyObj->isDeleted())
+      continue;
+
+    // Find position (this could be done faster, but probably not
+    // worth the trouble, since there won't be thousands of replies
+    // :-)
+
+    int i = 0; // index into m_repliesList
     while (i < m_repliesList.size() &&
            m_repliesList[i]->id() != replyId &&
            m_repliesList[i]->sortInt() < sortInt)
       i++;
-
-    if (m_repliesMap.contains(replyId))
-      continue;
-
-    if (i < m_repliesList.size() && m_repliesList[i]->id() == replyId)
+    
+    if (i < m_repliesList.size() && m_repliesList[i]->id() == replyId) {
+      qDebug() << "ERROR: addObjectList: item not in replies map!!";
       continue;
+    }
 
     FullObjectWidget* ow = new FullObjectWidget(replyObj, this, true);
     ObjectWidgetWithSignals::connectSignals(ow, this);
@@ -539,7 +588,12 @@ void FullObjectWidget::addObjectList(QASObjectList* ol) {
     m_repliesMap.insert(replyId);
   }
 
-  if (ol->hasMore() && (qulonglong)m_repliesList.size() < ol->totalItems()) {
+  PumpaSettings* settings = PumpaSettings::getSettings();
+
+  if (ol->hasMore() && 
+      ((qulonglong)m_repliesList.size() < ol->totalItems()) &&
+      (settings && 
+       m_object->replies()->apiLink().startsWith(settings->siteUrl()))) {
     addHasMoreButton(ol, li_before);
   } else if (m_hasMoreButton != NULL) {
     m_commentsLayout->removeWidget(m_hasMoreButton);
@@ -550,9 +604,8 @@ void FullObjectWidget::addObjectList(QASObjectList* ol) {
 
 //------------------------------------------------------------------------------
 
-void FullObjectWidget::addHasMoreButton(QASObjectList* ol, int li) {
-  QString buttonText = QString(tr("Show all %1 replies")).
-    arg(ol->totalItems());
+void FullObjectWidget::addHasMoreButton(QASObjectList*, int li) {
+  QString buttonText = tr("Show all replies");
   if (m_hasMoreButton == NULL) {
     m_hasMoreButton = new QPushButton(this);
     m_hasMoreButton->setFocusPolicy(Qt::NoFocus);
@@ -636,6 +689,13 @@ void FullObjectWidget::onDeleteClicked() {
 
 //------------------------------------------------------------------------------
 
+void FullObjectWidget::onEditClicked() {
+  if (m_author && m_author->isYou())
+    emit editObject(m_object);
+}
+
+//------------------------------------------------------------------------------
+
 void FullObjectWidget::onRepeatClicked() {
   QString msg = QString(tr("Share this %1 by %2?")).
     arg(typeName()).arg(m_author->displayNameOrWebFinger()) +
@@ -674,6 +734,24 @@ void FullObjectWidget::onFollowAuthor() {
 
 //------------------------------------------------------------------------------
 
+#ifdef DEBUG_BUTTONS
+
+void FullObjectWidget::onLoadRepliesClicked() {
+  if (m_object)
+    refreshObject(m_object->replies());
+}
+
+//------------------------------------------------------------------------------
+
+void FullObjectWidget::onDumpJsonClicked() {
+  if (m_object)
+    qDebug() << debugDumpJson(m_object->json(), "JSON");
+}
+
+#endif
+
+//------------------------------------------------------------------------------
+
 QString FullObjectWidget::processText(QString old_text, bool getImages) {
   if (s_allowedTags.isEmpty()) {
     s_allowedTags 
@@ -727,13 +805,17 @@ QString FullObjectWidget::processText(QString old_text, bool getImages) {
           QString imgSrc = rxi.cap(1);
           // qDebug() << "[DEBUG] processText: img" << imgSrc;
           
-          FileDownloader* fd = FileDownloader::get(imgSrc, true);
-          connect(fd, SIGNAL(fileReady()), this, SLOT(onChanged()),
-                  Qt::UniqueConnection);
-          if (fd->ready())
+	  FileDownloadManager* fdm = FileDownloadManager::getManager();
+
+	  if (fdm->hasFile(imgSrc)) {
             imagePlaceholder = 
               QString("<a href=\"%2\"><img border=\"0\" src=\"%1\" /></a>").
-              arg(fd->fileName()).arg(imgSrc);
+              arg(fdm->fileName(imgSrc)).arg(imgSrc);
+	  } else if (!imgSrc.isEmpty()) {
+	    FileDownloader* fd = fdm->download(imgSrc);
+	    connect(fd, SIGNAL(fileReady()), this, SLOT(onChanged()),
+		    Qt::UniqueConnection);
+	  }
         }
       }
       text.replace(pos, len, imagePlaceholder);
