@@ -75,6 +75,12 @@ private slots:
   void onFollowAuthor();
   void updateFollowAuthorButton(bool wait = false);
   void onDeleteClicked();
+  void onEditClicked();
+
+#ifdef DEBUG_BUTTONS
+  void onLoadRepliesClicked();
+  void onDumpJsonClicked();
+#endif
 
 private:
   QString typeName() const;
@@ -86,6 +92,7 @@ private:
 
   void updateLikes();
   void updateShares();
+  void updateTitle();
 
   QString recipientsToString(QASObjectList* rec);
   QString processText(QString old_text, bool getImages=false);
@@ -120,9 +127,15 @@ private:
   TextToolButton* m_followButton;
   TextToolButton* m_followAuthorButton;
   TextToolButton* m_deleteButton;
+  TextToolButton* m_editButton;
 
   TextToolButton* m_lessButton;
 
+#ifdef DEBUG_BUTTONS
+  TextToolButton* m_loadRepliesButton;
+  TextToolButton* m_dumpJsonButton;
+#endif
+
   QVBoxLayout* m_contentLayout;
   QHBoxLayout* m_buttonLayout;
   QVBoxLayout* m_commentsLayout;
