@@ -29,6 +29,8 @@
 #include <QFormLayout>
 #include <QLineEdit>
 #include <QCheckBox>
+#include <QScrollArea>
+#include <QSplitter>
 
 #include "messageedit.h"
 #include "qactivitystreams.h"
@@ -39,6 +41,21 @@
 
 //------------------------------------------------------------------------------
 
+class PictureLabel : public QLabel {
+  Q_OBJECT
+
+ public:
+  PictureLabel(QWidget* parent);
+  void setOriginalPixmap(QPixmap);
+  
+ protected:
+  virtual void resizeEvent(QResizeEvent* event);
+  
+  QPixmap m_originalPixmap;
+};
+
+//------------------------------------------------------------------------------
+
 class MessageWindow : public QDialog {
   Q_OBJECT
 
@@ -47,6 +64,7 @@ public:
   virtual void accept();
 
   void newMessage(QASObject* obj, QASObjectList* to, QASObjectList* cc);
+  void editMessage(QASObject* obj);
   void clear();
   void setCompletions(const MessageEdit::completion_t* completions);
 
@@ -57,18 +75,20 @@ signals:
   void sendMessage(QString, QString, RecipientList, RecipientList);
   void sendImage(QString, QString, QString, RecipientList, RecipientList);
   void sendReply(QASObject*, QString, RecipientList, RecipientList);
+  void sendEdit(QASObject*, QString, QString);
 
 private slots:
   void onAddPicture();
   void onRemovePicture();
   void togglePreview();
-  void updatePreview();
+  void updatePreview(bool force=false);
   void onAddRecipient(QASActor*);
   void onAddTo();
   void onAddCc();
   void onMarkdownChecked(int);
 
 private:
+  void initWindow(QString title, QString buttonText, bool showRecipients);
   void addRecipientWindow(MessageRecipients*, QString);
   void updateAddPicture();
 
@@ -99,8 +119,10 @@ private:
   QLabel* m_ccLabel;
 
   RichTextLabel* m_previewLabel;
+  QScrollArea* m_previewArea;
+  QSplitter* m_splitter;
 
-  QLabel* m_pictureLabel;
+  PictureLabel* m_pictureLabel;
   QLineEdit* m_title;
 
   QPushButton* m_cancelButton;
@@ -115,6 +137,9 @@ private:
   QMap<QString, QASObject*> m_recipientSelection;
   QStringList m_recipientList;
 
+  bool m_editing;
+  bool m_isReply;
+
   QASObject* m_obj;
   PumpaSettings* m_s;
   const RecipientList* m_rl;
