@@ -1,5 +1,5 @@
 /*
-  Copyright 2013 Mats Sjöberg
+  Copyright 2014 Mats Sjöberg
   
   This file is part of the Pumpa programme.
 
@@ -42,7 +42,8 @@ PumpApp::PumpApp(PumpaSettings* settings, QString locale, QWidget* parent) :
   m_messageWindow(NULL),
   m_trayIcon(NULL),
   m_locale(locale),
-  m_uploadDialog(NULL)
+  m_uploadDialog(NULL),
+  m_uploadRequest(NULL)
 {
   if (m_locale.isEmpty())
     m_locale = "en_US";
@@ -87,6 +88,8 @@ PumpApp::PumpApp(PumpaSettings* settings, QString locale, QWidget* parent) :
   connect(m_oam, SIGNAL(sslErrors(QNetworkReply*, QList<QSslError>)), 
           this, SLOT(onSslErrors(QNetworkReply*, QList<QSslError>)));
 
+  m_fdm = FileDownloadManager::getManager(this);
+
   createActions();
   createMenu();
 
@@ -110,6 +113,7 @@ PumpApp::PumpApp(PumpaSettings* settings, QString locale, QWidget* parent) :
   int max_fh = m_s->maxFirehoseItems();
 
   m_tabWidget = new TabWidget(this);
+  m_tabWidget->setFocusPolicy(Qt::NoFocus);
 
   m_inboxWidget = new CollectionWidget(this, max_tl);
   connectCollection(m_inboxWidget);
@@ -174,7 +178,7 @@ PumpApp::PumpApp(PumpaSettings* settings, QString locale, QWidget* parent) :
   setCentralWidget(m_tabWidget);
 
   // oaRequest->setEnableDebugOutput(true);
-  syncOAuthInfo();
+  // syncOAuthInfo();
 
   m_timerId = -1;
 
@@ -235,6 +239,9 @@ void PumpApp::onSslErrors(QNetworkReply* reply, QList<QSslError> errors) {
   }
 
   QString infoText;
+  if (reply)
+    infoText += "URL: " + reply->url().toString() + "\n";
+
   for (int i=0; i<errors.size(); i++) {
     infoText += tr("SSL Error: ") + errors[i].errorString() + ".\n";
   }
@@ -255,6 +262,9 @@ void PumpApp::onSslErrors(QNetworkReply* reply, QList<QSslError> errors) {
       tr("MD5 digest: ") + cert.digest().toHex() + "\n";
   }
 
+  qDebug() << infoText;
+  qDebug() << detailText;
+
   QMessageBox msgBox;
   msgBox.setText(tr("<b>Untrusted SSL connection!</b>"));
   msgBox.setIcon(QMessageBox::Critical);
@@ -329,6 +339,8 @@ void PumpApp::connectCollection(ASWidget* w, bool highlight) {
   connect(w, SIGNAL(follow(QString, bool)), this, SLOT(follow(QString, bool)));
   connect(w, SIGNAL(deleteObject(QASObject*)),
           this, SLOT(onDeleteObject(QASObject*)));
+  connect(w, SIGNAL(editObject(QASObject*)),
+	  this, SLOT(onEditObject(QASObject*)));
 }
 
 //------------------------------------------------------------------------------
@@ -346,7 +358,7 @@ void PumpApp::onClientRegistered(QString userName, QString siteUrl,
 void PumpApp::onAccessTokenReceived(QString token, QString tokenSecret) {
   m_s->token(token);
   m_s->tokenSecret(tokenSecret);
-  syncOAuthInfo();
+  // syncOAuthInfo();
 
   startPumping();
 }
@@ -365,6 +377,7 @@ bool PumpApp::haveOAuth() {
 void PumpApp::tabSelected(int index) {
   m_tabWidget->deHighlightTab(index);
   resetNotifications();
+  m_closeTabAction->setEnabled(m_tabWidget->closable(index));
 }
 
 //------------------------------------------------------------------------------
@@ -398,6 +411,8 @@ void PumpApp::debugAction() {
   qDebug() << "inbox" << m_inboxWidget->count();
   qDebug() << "meanwhile" << m_inboxMinorWidget->count();
   qDebug() << "firehose" << m_firehoseWidget->count();
+
+  m_fdm->dumpStats();
 }
 
 //------------------------------------------------------------------------------
@@ -414,14 +429,6 @@ void PumpApp::refreshTimeLabels() {
 
 //------------------------------------------------------------------------------
 
-void PumpApp::syncOAuthInfo() {
-  FileDownloader::setOAuthInfo(m_s->siteUrl(), m_s->clientId(),
-                               m_s->clientSecret(),
-                               m_s->token(), m_s->tokenSecret());
-}
-
-//------------------------------------------------------------------------------
-
 void PumpApp::statusMessage(const QString& msg) {
   statusBar()->showMessage(msg);
 }
@@ -474,15 +481,23 @@ void PumpApp::timelineHighlighted(int feed) {
 
   // Popup notifications.
   if (doPopup) {
+    int actsCount = 0;
+    for (int i=0; i<acts.size(); i++)
+      if (!acts.at(i)->skipNotify())
+	actsCount++;
+
+    if (actsCount == 0)
+      return;
+
     QString msg =
-      QString(tr("You have %1 new notifications.")).arg(acts.count());
+      QString(tr("You have %1 new notifications.")).arg(actsCount);
 
     // If there's only a single post activity we'll make the
     // notification more informative.
     QASActivity* act = acts.at(0);
     QASObject* obj = act->object();
     QASActor* actor = act->actor();
-    if (acts.count() == 1 && act->verb() == "post" && obj && actor) {
+    if (actsCount == 1 && act->verb() == "post" && obj && actor) {
       QString actorName = actor->displayNameOrWebFinger();
       if (obj->type() == "comment")
         msg = QString(tr("%1 commented: ")).arg(actorName);
@@ -669,6 +684,11 @@ void PumpApp::createActions() {
   connect(m_debugAction, SIGNAL(triggered()), this, SLOT(debugAction()));
   addAction(m_debugAction);
   
+  m_closeTabAction = new QAction("Close tab", this);
+  m_closeTabAction->setShortcut(tr("Ctrl+W"));
+  connect(m_closeTabAction, SIGNAL(triggered()), this, SLOT(closeTab()));
+  m_closeTabAction->setEnabled(false);
+
   m_firehoseAction = new QAction(tr("Firehose"), this);
   connect(m_firehoseAction, SIGNAL(triggered()), this, SLOT(showFirehose()));
 
@@ -711,6 +731,7 @@ void PumpApp::createMenu() {
   m_tabsMenu->addAction(m_followersAction);
   m_tabsMenu->addAction(m_followingAction);
   m_tabsMenu->addAction(m_firehoseAction);
+  m_tabsMenu->addAction(m_closeTabAction);
   menuBar()->addMenu(m_tabsMenu);
 
   helpMenu = new QMenu(tr("&Help"), this);
@@ -764,7 +785,7 @@ void PumpApp::about() {
   
   QString mainText = 
     QString("<p><b>%1 %2</b> - %3<br/><a href=\"%4\">%4</a><br/>"
-            + tr("Copyright &copy; 2013 Mats Sj&ouml;berg")
+            + tr("Copyright &copy; 2014 Mats Sj&ouml;berg")
             + " - <a href=\"https://pump.saz.im/sazius\">sazius@pump.saz.im</a>."
             "</p>"
             + tr("<p>Report bugs and feature requests at "
@@ -781,7 +802,8 @@ void PumpApp::about() {
 
 //------------------------------------------------------------------------------
 
-void PumpApp::newNote(QASObject* obj, QASObjectList* to, QASObjectList* cc) {
+void PumpApp::newNote(QASObject* obj, QASObjectList* to, QASObjectList* cc,
+		      bool edit) {
   if (!m_messageWindow) {
     m_messageWindow = new MessageWindow(m_s, &m_recipientLists, this);
     connect(m_messageWindow,
@@ -796,10 +818,14 @@ void PumpApp::newNote(QASObject* obj, QASObjectList* to, QASObjectList* cc) {
                                               RecipientList, RecipientList)),
             this, SLOT(postReply(QASObject*, QString,
                                  RecipientList, RecipientList)));
+    connect(m_messageWindow, SIGNAL(sendEdit(QASObject*, QString, QString)),
+	    this, SLOT(postEdit(QASObject*, QString, QString)));
     m_messageWindow->setCompletions(&m_completions);
   }
-
-  m_messageWindow->newMessage(obj, to, cc);
+  if (edit)
+    m_messageWindow->editMessage(obj);
+  else
+    m_messageWindow->newMessage(obj, to, cc);
   m_messageWindow->show();
 }
 
@@ -814,7 +840,8 @@ void PumpApp::reload() {
 
 void PumpApp::fetchAll(bool all) {
   m_inboxWidget->fetchNewer();
-  m_inboxWidget->refresh();
+  if (m_inboxWidget->linksInitialised())
+    m_inboxWidget->refresh();
   m_directMinorWidget->fetchNewer();
   m_directMajorWidget->fetchNewer();
   m_inboxMinorWidget->fetchNewer();
@@ -1024,6 +1051,12 @@ void PumpApp::onShowContext(QASObject* obj) {
 
 //------------------------------------------------------------------------------
 
+void PumpApp::closeTab() {
+  m_tabWidget->closeCurrentTab();
+}
+
+//------------------------------------------------------------------------------
+
 void PumpApp::showFirehose() {
   if (!tabShown(m_firehoseWidget))
     m_tabWidget->addTab(m_firehoseWidget, tr("Fi&rehose"), true, true);
@@ -1077,14 +1110,31 @@ void PumpApp::postNote(QString content, QString title,
   QVariantMap obj;
   obj["objectType"] = "note";
   obj["content"] = addTextMarkup(content, m_s->useMarkdown());
-  if (!title.isEmpty())
-    obj["displayName"] = processTitle(title);
+
+  QString ptitle = processTitle(title);
+  if (!ptitle.isEmpty())
+    obj["displayName"] = ptitle;
 
   feed("post", obj, QAS_OBJECT | QAS_REFRESH | QAS_POST, to, cc);
 }
 
 //------------------------------------------------------------------------------
 
+void PumpApp::postEdit(QASObject* obj, QString content, QString title) {
+  QVariantMap json;
+  json["id"] = obj->id();
+  json["objectType"] = obj->type();
+  json["content"] = addTextMarkup(content, m_s->useMarkdown());
+
+  QString ptitle = processTitle(title);
+  if (!ptitle.isEmpty())
+    json["displayName"] = ptitle;
+
+  feed("update", json, QAS_OBJECT | QAS_REFRESH | QAS_POST);
+}
+
+//------------------------------------------------------------------------------
+
 void PumpApp::postImage(QString msg,
                         QString title,
                         QString imageFile,
@@ -1134,12 +1184,15 @@ void PumpApp::uploadFile(QString filename) {
     m_uploadDialog = new QProgressDialog("Uploading image...", "Abort", 0, 100,
                                          this);
     m_uploadDialog->setWindowModality(Qt::WindowModal);
+    connect(m_uploadDialog, SIGNAL(canceled()), this, SLOT(uploadCanceled()));
+  } else {
+    m_uploadDialog->reset();
   }
   m_uploadDialog->setValue(0);
   m_uploadDialog->show();
 
-  const QNetworkReply* nr = executeRequest(oaRequest, QAS_IMAGE_UPLOAD);
-  connect(nr, SIGNAL(uploadProgress(qint64, qint64)),
+  m_uploadRequest = executeRequest(oaRequest, QAS_IMAGE_UPLOAD);
+  connect(m_uploadRequest, SIGNAL(uploadProgress(qint64, qint64)),
           this, SLOT(uploadProgress(qint64, qint64)));
 }
 
@@ -1169,13 +1222,22 @@ void PumpApp::uploadProgress(qint64 bytesSent, qint64 bytesTotal) {
   if (!m_uploadDialog || bytesTotal <= 0)
     return;
 
-  QNetworkReply *reply = qobject_cast<QNetworkReply *>(sender());
-
   m_uploadDialog->setValue((100*bytesSent)/bytesTotal);
-  if (m_uploadDialog->wasCanceled() && reply) {
-    reply->abort();
-    m_uploadDialog->hide();
+}
+
+//------------------------------------------------------------------------------
+
+void PumpApp::uploadCanceled(bool abortRequest) {
+  if (m_uploadRequest && abortRequest) {
+#ifdef DEBUG_NET
+    qDebug() << "[DEBUG] aborting upload...";
+#endif
+    m_uploadRequest->abort();
   }
+  m_uploadRequest = NULL;
+
+  m_imageObject.clear();
+  m_uploadDialog->reset();
 }
 
 //------------------------------------------------------------------------------
@@ -1225,6 +1287,12 @@ void PumpApp::onDeleteObject(QASObject* obj) {
 
 //------------------------------------------------------------------------------
 
+void PumpApp::onEditObject(QASObject* obj) {
+  newNote(obj, NULL, NULL, true);
+}
+
+//------------------------------------------------------------------------------
+
 void PumpApp::addRecipient(QVariantMap& data, QString name, RecipientList to) {
   if (to.isEmpty())
     return;
@@ -1372,7 +1440,7 @@ QNetworkReply* PumpApp::executeRequest(KQOAuthRequest* request,
 void PumpApp::followActor(QASActor* actor, bool doFollow) {
   actor->setFollowed(doFollow);
 
-  QString from = QString("%2 (%1)").arg(actor->displayName()).
+  QString from = QString("%1 (%2)").arg(actor->displayName()).
     arg(actor->webFinger());
 
   if (from.isEmpty() || from.startsWith("http://") ||
@@ -1427,6 +1495,9 @@ void PumpApp::onAuthorizedRequestReady(QByteArray response, int rid) {
     if (id & QAS_POST) {
       errorMessage(tr("Unable to post message!"));
       m_messageWindow->show();
+    } else if (sid == QAS_IMAGE_UPLOAD) {
+      uploadCanceled(false);
+      errorMessage(tr("Unable to upload image!"));
     } else if (sid == QAS_OBJECT) {
       qDebug() << "[WARNING] unable to fetch context for object.";
     } else {
@@ -1484,13 +1555,13 @@ void PumpApp::onAuthorizedRequestReady(QByteArray response, int rid) {
       m_recipientLists.append(lists->at(i));
     }
   } else if (sid == QAS_IMAGE_UPLOAD) {
-    m_uploadDialog->hide();
+    m_uploadDialog->reset();
     updatePostedImage(json);
   } else if (sid == QAS_IMAGE_UPDATE) {
     postImageActivity(json);
   }
 
-  if ((id & QAS_POST) && m_messageWindow)
+  if ((id & QAS_POST) && m_messageWindow && !m_messageWindow->isVisible())
     m_messageWindow->clear();
 
   if (id & QAS_REFRESH) { 
