@@ -50,6 +50,7 @@
 #include "contextwidget.h"
 #include "objectlistwidget.h"
 #include "messagewindow.h"
+#include "filedownloader.h"
 
 //------------------------------------------------------------------------------
 
@@ -83,8 +84,10 @@ private slots:
                  RecipientList to, RecipientList cc);
   void postReply(QASObject* replyToObj, QString content,
                  RecipientList to, RecipientList cc);
+  void postEdit(QASObject* obj, QString content, QString title);
   void follow(QString acctId, bool follow);
   void onDeleteObject(QASObject* obj);
+  void onEditObject(QASObject* obj);
 
   void errorMessage(QString msg);
   void notifyMessage(QString msg);
@@ -98,6 +101,7 @@ private slots:
   void onAuthorizedRequestReady(QByteArray response, int id);
 
   void uploadProgress(qint64 bytesSent, qint64 bytesTotal);
+  void uploadCanceled(bool abortRequest=true);
   
   void request(QString endpoint, int response_id,
                KQOAuthRequest::RequestHttpMethod method = KQOAuthRequest::GET,
@@ -107,7 +111,7 @@ private slots:
   void about();
   void preferences();
   void newNote(QASObject* obj = NULL, QASObjectList* to = NULL,
-               QASObjectList* cc = NULL);
+               QASObjectList* cc = NULL, bool edit = false);
   void reload();
   void loadOlder();
 
@@ -122,6 +126,7 @@ private slots:
   void showFavourites();
   void showUserActivities();
   void showFirehose();
+  void closeTab();
 
 protected:
   void timerEvent(QTimerEvent*);
@@ -183,8 +188,6 @@ private:
 
   void refreshTimeLabels();
 
-  void syncOAuthInfo();
-
   void fetchAll(bool);
   QString inboxEndpoint(QString path);
 
@@ -221,12 +224,15 @@ private:
   QAction* m_favouritesAction;
   QAction* m_userActivitiesAction;
   QAction* m_firehoseAction;
+  QAction* m_closeTabAction;
   QMenu* m_tabsMenu;
 
   QAction* m_debugAction;
 
   KQOAuthManager *m_oam;
 
+  FileDownloadManager* m_fdm;
+
   TabWidget* m_tabWidget;
   CollectionWidget* m_inboxWidget;
   CollectionWidget* m_directMajorWidget;
@@ -267,6 +273,7 @@ private:
   MessageEdit::completion_t m_completions;
 
   QProgressDialog* m_uploadDialog;
+  QNetworkReply* m_uploadRequest;
 
   QNetworkAccessManager* m_nam;
 
