@@ -32,9 +32,12 @@
 class PumpaSettings : public QObject {
   Q_OBJECT
 
-public:
   PumpaSettings(QString filename="", QObject* parent=0);
 
+public:
+  static PumpaSettings* getSettings(bool create=false, QString filename="",
+				    QObject* parent=0);
+
   bool firstStart() const { return m_firstStart; }
 
   bool contains(QString key) const { return m_s->contains(key); }
@@ -117,6 +120,10 @@ public:
     return getValue("minimise_authors", QStringList()).toStringList();
   }
 
+  bool showPreview() const {
+    return getValue("show_preview", false).toBool();
+  }
+
   // setters
   void siteUrl(QString s) { setValue("site_url", s, "Account"); }
   void userName(QString s) { setValue("username", s, "Account"); }
@@ -150,6 +157,8 @@ public:
 
   void hideAuthors(QStringList sl) { setValue("minimise_authors", sl); }
 
+  void showPreview(bool b) { setValue("show_preview", b); }
+
 signals:
   void trayIconChanged();
 
@@ -163,6 +172,8 @@ private:
   bool m_firstStart;
 
   QSettings* m_s;
+
+  static PumpaSettings* s_settings;
 };
 
 #endif /* _PUMPASETTINGS_H_ */
