@@ -53,6 +53,8 @@ void QASActor::update(QVariantMap json) {
   bool ch = false;
   bool dummy = false;
 
+  m_json = json;
+
   m_author = NULL;
 
   updateVar(json, m_url, "url", ch); 
@@ -60,6 +62,9 @@ void QASActor::update(QVariantMap json) {
   updateVar(json, m_objectType, "objectType", ch);
   updateVar(json, m_preferredUsername, "preferredUsername", ch);
 
+  updateVar(json, m_published, "published", ch);
+  updateVar(json, m_updated, "updated", ch);
+
   m_webFinger = m_id;
   if (m_webFinger.startsWith("http://") || m_webFinger.startsWith("https://"))
     m_webFinger = m_preferredUsername;
