@@ -65,7 +65,9 @@ int QASObject::connections() const {
 
 QASLocation::QASLocation(QObject* parent) :
   QObject(parent),
-  m_hasPosition(true) {}
+  m_latitude(-1.0),
+  m_longitude(-1.0),
+  m_hasPosition(false) {}
 
 //------------------------------------------------------------------------------
 
@@ -121,6 +123,8 @@ void QASObject::update(QVariantMap json, bool ignoreLike) {
   bool ch = false;
   bool wasDeleted = isDeleted();
 
+  m_json = json;
+
   updateVar(json, m_objectType, "objectType", ch);
   updateVar(json, m_url, "url", ch);
   updateVar(json, m_content, "content", ch);
@@ -306,7 +310,23 @@ QASActor* QASObject::asActor() {
 
 //------------------------------------------------------------------------------
 
+QString QASObject::deletedText() const {
+  return "<i>[" + QString(tr("Deleted %1")).arg(deletedDate().toString()) + 
+    "]</i>";
+}
+
+//------------------------------------------------------------------------------
+
+QString QASObject::content() const {
+  return isDeleted() ? deletedText() : m_content;
+}
+
+//------------------------------------------------------------------------------
+
 QString QASObject::excerpt() const {
+  if (isDeleted())
+    return deletedText();
+
   QString text = displayName();
   if (text.isEmpty()) {
     text = content();
