@@ -24,8 +24,8 @@
 //------------------------------------------------------------------------------
 
 TabWidget::TabWidget(QWidget* parent) : QTabWidget(parent) {
-  sMap = new QSignalMapper(this);
-  connect(sMap, SIGNAL(mapped(int)), this, SLOT(highlightTab(int)));
+  m_sMap = new QSignalMapper(this);
+  connect(m_sMap, SIGNAL(mapped(int)), this, SLOT(highlightTab(int)));
   setTabsClosable(true);
 
   connect(tabBar(), SIGNAL(tabCloseRequested(int)),
@@ -45,7 +45,7 @@ int TabWidget::addTab(QWidget* page, const QString& label,
     tabBar()->setTabButton(index, QTabBar::LeftSide, 0);
     tabBar()->setTabButton(index, QTabBar::RightSide, 0);
   } else {
-    okToClose.insert(index);
+    m_okToClose.insert(index);
   }
 
   return index;
@@ -53,8 +53,14 @@ int TabWidget::addTab(QWidget* page, const QString& label,
 
 //------------------------------------------------------------------------------
 
+void TabWidget::closeCurrentTab() {
+  closeTab(currentIndex());
+}
+
+//------------------------------------------------------------------------------
+
 void TabWidget::closeTab(int index) {
-  if (!okToClose.contains(index)) {
+  if (!closable(index)) {
     qDebug() << "[ERROR] Tried to close unclosable tab" << index;
     return;
   }
@@ -82,8 +88,8 @@ void TabWidget::deHighlightTab(int index) {
 //------------------------------------------------------------------------------
 
 void TabWidget::addHighlightConnection(QWidget* page, int index) {
-  sMap->setMapping(page, index);
-  connect(page, SIGNAL(highlightMe()), sMap, SLOT(map()));
+  m_sMap->setMapping(page, index);
+  connect(page, SIGNAL(highlightMe()), m_sMap, SLOT(map()));
 }
 
 //------------------------------------------------------------------------------
